
# Alpha Compiler

Various tools for quantitative finance with Python.  Many tools for working with the Zipline open source library, and replicating Quantopian tools in your personal env.   

*Update May 2020 now tested with Python 3.5*


You can find details on Alpha Compiler [here](https://pbharrin.github.io/alpha-compiler/syntax "Title")
